@@ -87,7 +87,7 @@ cell2bool(lex_ctxt* lexic, tree_cell* c)
 
     case REF_ARRAY:
     case DYN_ARRAY:
-      nasl_perror(lexic, "cell2bool: converting array to boolean does not make sense!\n");
+      /*nasl_perror(lexic, "cell2bool: converting array to boolean does not make sense!\n");*/
       return 1;
 
     default:
