@@ -55,7 +55,7 @@ tree_cell * nasl_md2(lex_ctxt * lexic)
  if(data == NULL)
   return NULL;
  
- MD2(data, len, md);
+ MD2((unsigned char*)data, len, (unsigned char*)md);
 
  retc = alloc_tree_cell(0, NULL);
  retc->type = CONST_DATA;
@@ -74,7 +74,7 @@ tree_cell * nasl_md4(lex_ctxt * lexic)
  if(data == NULL)
   return NULL;
  
- MD4(data, len, md);
+ MD4((unsigned char*)data, len, (unsigned char*)md);
 
  retc = alloc_tree_cell(0, NULL);
  retc->type = CONST_DATA;
@@ -93,7 +93,7 @@ tree_cell * nasl_md5(lex_ctxt * lexic)
  if(data == NULL)
   return NULL;
  
- MD5(data, len, md);
+ MD5((unsigned char*)data, len, (unsigned char*)md);
 
  retc = alloc_tree_cell(0, NULL);
  retc->type = CONST_DATA;
@@ -112,7 +112,7 @@ tree_cell * nasl_sha(lex_ctxt * lexic)
  if(data == NULL)
   return NULL;
  
- SHA(data, len, md);
+ SHA((unsigned char*)data, len, (unsigned char*)md);
 
  retc = alloc_tree_cell(0, NULL);
  retc->type = CONST_DATA;
@@ -132,7 +132,7 @@ tree_cell * nasl_sha1(lex_ctxt * lexic)
  if(data == NULL)
   return NULL;
  
- SHA1(data, len, md);
+ SHA1((unsigned char*)data, len, (unsigned char*)md);
 
  retc = alloc_tree_cell(0, NULL);
  retc->type = CONST_DATA;
@@ -152,7 +152,7 @@ tree_cell * nasl_ripemd160(lex_ctxt * lexic)
  if(data == NULL)
   return NULL;
  
- RIPEMD160(data, len, md);
+ RIPEMD160((unsigned char*)data, len, (unsigned char*)md);
 
  retc = alloc_tree_cell(0, NULL);
  retc->type = CONST_DATA;
@@ -175,7 +175,7 @@ static tree_cell * nasl_hmac(lex_ctxt * lexic, const EVP_MD * evp_md)
  int data_len = get_local_var_size_by_name(lexic, "data");
  int  key_len = get_local_var_size_by_name(lexic, "key");
  char hmac[EVP_MAX_MD_SIZE + 1];
- int len = 0;
+ unsigned int len = 0;
  tree_cell * retc;
  
  /* if(data == NULL || key == NULL)
@@ -184,7 +184,7 @@ static tree_cell * nasl_hmac(lex_ctxt * lexic, const EVP_MD * evp_md)
   return NULL;
  }
  */
- HMAC(evp_md, key, key_len, data, data_len, hmac, &len);
+ HMAC(evp_md, key, key_len, (unsigned char*)data, data_len, (unsigned char*)hmac, &len);
  retc = alloc_tree_cell(0, NULL);
  retc->type = CONST_DATA;
  retc->size = len;
