@@ -188,11 +188,7 @@ nasl_func_call(lex_ctxt* lexic, const nasl_func* f, tree_cell* arg_list)
 	else
 	  {
 	    size_t num = f->nb_named_args;
-	    if (lfind(&pc->x.str_val, f->args_names, &num,
-		      sizeof(char*), stringcompare) == NULL)
-	      nasl_perror(lexic, "No such arg '%s' for function '%s' - might be ignored\n",
-		      pc->x.str_val, f->func_name);
-	    else
+	    if (lfind(&pc->x.str_val, f->args_names, &num, sizeof(char*), stringcompare) != NULL)
 	      nb_n ++;
 	  }
   
