@@ -233,6 +233,11 @@ tryagain :
      else  
           return NULL;
    }
+   else if ( errno != EINPROGRESS )
+   { 
+     close(sock);
+     return NULL;
+   }
  }
 
   do {
@@ -243,6 +248,12 @@ tryagain :
   e = select(sock + 1, NULL, &rd, NULL, to > 0 ? &tv:NULL);
   } while ( e < 0 && errno == EINTR );
 
+ if ( e <= 0 ) 
+ {
+   close ( sock );
+   return FAKE_CELL;
+ }
+
  block_socket(sock);
  opt_sz = sizeof(opt);
 
@@ -554,6 +565,7 @@ tree_cell * nasl_send(lex_ctxt * lexic)
  char * data = get_str_local_var_by_name(lexic, "data");
  int option = get_int_local_var_by_name(lexic, "option", 0);
  int length = get_int_local_var_by_name(lexic, "length", 0);
+ int data_length = get_var_size_by_name(lexic, "data");
  int n;
  tree_cell * retc;
  int type;
@@ -567,8 +579,8 @@ tree_cell * nasl_send(lex_ctxt * lexic)
 	return NULL;
  }
 
- if( length == 0 )
-	length = get_var_size_by_name(lexic, "data");
+ if( length <= 0 || length > data_length )
+	length = data_length;
  
  
  if(!fd_is_stream(soc) && 
