@@ -516,7 +516,7 @@ copy_anon_var(anon_nasl_var* v1, const anon_nasl_var *v2)
       break;
 
     case VAR2_ARRAY:
-      copy_array(&v1->v.v_arr, &v2->v.v_arr, 0);
+      copy_array(&v1->v.v_arr, &v2->v.v_arr, 1);
       break;
 
     default:
@@ -654,6 +654,13 @@ affect_to_anon_var(anon_nasl_var* v1, tree_cell* rval)
 
     case REF_VAR:
       v2 = rval->x.ref_val;
+      if ( v2 == NULL )
+	{
+	  t2 = 0;
+	  a = NULL;
+	  break;
+	}
+
       if (v2 == v1)
 	{
 #if NASL_DEBUG > 1
@@ -661,6 +668,7 @@ affect_to_anon_var(anon_nasl_var* v1, tree_cell* rval)
 #endif
 	  return FAKE_CELL;
 	}
+
       t2 = v2->var_type;
       if (t2 == VAR2_ARRAY)
 	a = &v2->v.v_arr;	/* ? */
